@@ -27,20 +27,6 @@ use XAS::Class
         t => 1024 * 1024 * 1204 * 1024
     }
   },
-  messages => {
-    processing  => "processing %s in %s",
-    age_params  => "age parameter '%s' should match \\d+\\s+[smhdw]",
-    size_params => "size parameter '%s' should match \\d+\\s+[bkmg]",
-    compressing => "compressing %s",
-    copied      => "copied %s to %s",
-    moved       => "moved %s to %s",
-    nocompress  => "compression failed for %s",
-    norecreate  => "unable to recreate %s",
-    notail      => "unable to copy %s lines into %s",
-    noexist     => "%s did not exist",
-    nomatch     => "nothing in %s to match %s",
-    nochange    => "unable to change to %s"
-  },
 ;
 
 # ----------------------------------------------------------------------
@@ -329,7 +315,7 @@ sub recreate_file {
             }
 
             $self->run_cmd($cmd);
-            $self->log->error_msg(('notail', $line_count, $filename) if $?;
+            $self->log->error_msg('notail', $line_count, $filename) if $?;
 
         }
 
@@ -594,7 +580,7 @@ sub options {
 
     return {
         'cfgfile=s' => sub { 
-            $cfgfile} = File($_[1]); 
+            my $cfgfile = File($_[1]); 
             $self->env->cfgfile($cfgfile);
         },
     };
@@ -781,7 +767,7 @@ Scan the local directory looking for files to rotate.
 
 =head1 SEE ALSO
 
-L< Rotate|Rotate>
+L<Rotate|Rotate>
 
 =head1 AUTHOR
 
@@ -791,10 +777,8 @@ Kevin L. Esteb, E<lt>kevin@kesteb.usE<gt>
 
 Copyright (C) 2014 Kevin L. Esteb
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.8 or,
-at your option, any later version of Perl 5 you may have available.
-
-See L<http://dev.perl.org/licenses/> for more information.
+TThis is free software; you can redistribute it and/or modify it under
+the terms of the Artistic License 2.0. For details, see the full text
+of the license at http://www.perlfoundation.org/artistic_license_2_0.
 
 =cut
