@@ -1,6 +1,6 @@
 package XAS::Lib::App;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use Try::Tiny;
 use Pod::Usage;
@@ -17,9 +17,9 @@ use XAS::Class
   filesystem => 'File',
   vars => {
     PARAMS => {
-      -throws   => { optional => 1, default => 'changeme' },
-      -facility => { optional => 1, default => 'systems' },
-      -priority => { optional => 1, default => 'low' },
+      -throws   => { optional => 1, default => undef },
+      -facility => { optional => 1, default => undef },
+      -priority => { optional => 1, default => undef },
     }
   }
 ;
@@ -108,7 +108,24 @@ sub init {
 
     my $self = $class->SUPER::init(@_);
 
-    $self->class->throws($self->throws);
+    if (defined($self->throws)) {
+
+        $self->env->throws($self->throws);
+        $self->class->throws($self->throws);
+
+    }
+
+    if (defined($self->priority)) {
+
+        $self->env->priority($self->priority);
+
+    }
+
+    if (defined($self->facility)) {
+
+        $self->env->facility($self->facility);
+
+    }
 
     my $options = $self->options();
     my $defaults = $self->_default_options();
@@ -126,21 +143,33 @@ sub _default_options {
     my $script  = $self->env->script;
 
     return {
-        'log-type=s'     => sub { $self->env->log_type($_[1]); },
-        'log-facility=s' => sub { $self->env->log_facility($_[1]); },
-        'alerts!'        => sub { $self->env->alerts($_[1]); },
-        'help|h|?'       => sub { pod2usage(-verbose => 0, -exitstatus => 0); },
-        'manual'         => sub { pod2usage(-verbose => 2, -exitstatus => 0); },
-        'version'        => sub { printf("%s - v%s\n", $script, $version); exit 0; },
-        'debug'          => sub { 
+        'alerts!'  => sub { $self->env->alerts($_[1]); },
+        'help|h|?' => sub { pod2usage(-verbose => 0, -exitstatus => 0); },
+        'manual'   => sub { pod2usage(-verbose => 2, -exitstatus => 0); },
+        'version'  => sub { printf("%s - v%s\n", $script, $version); exit 0; },
+        'debug'    => sub { 
             $self->env->xdebug(1); 
             $self->log->level('debug', 1);
         },
-        'logfile=s' => sub {
+        'priority=s' => sub {
+            $self->env->priority($_[1]);
+        },
+        'facility=s' => sub {
+            $self->env->facility($_[1]);
+        },
+        'log-file=s' => sub {
             my $logfile = File($_[1]);
             $self->env->log_type('file');
-            $self->env->logfile($logfile);
-        }
+            $self->env->log_file($logfile);
+            $self->log->activate();
+        },
+        'log-type=s' => sub { 
+            $self->env->log_type($_[1]);
+            $self->log->activate();
+        },
+        'log-facility=s' => sub { 
+            $self->env->log_facility($_[1]); 
+        },
     };
 
 }
@@ -180,8 +209,8 @@ signal handling, options processing, along with a exit handler.
 
 =head2 new
 
-This method initilaizes the module. It inherits from XAS::Base and takes 
-these additional parameters:
+This method initializes the module. It inherits from L<XAS::Base|XAS::Base>
+and takes these additional parameters:
 
 =over 4
 
@@ -202,7 +231,7 @@ This will change the priority of the alert. The default is 'low'.
 =head2 run
 
 This method sets up a global exception handler and calls main(). The main() 
-method will be passed one parameter: an initialised handle to this class.
+method will be passed one parameter: an initialized handle to this class.
 
 Example
 
@@ -306,6 +335,16 @@ The signal that was captured.
 
 This module handles the following command line options.
 
+=head2 --facility
+
+Defines the facility to use. Defaults to 'systems'. This will override the
+class parameter.
+
+=head2 --priority
+
+Defines the priority to use. Defaults to 'low'. This will override the
+class parameter.
+
 =head2 --debug
 
 This toggles debugging output.
@@ -336,7 +375,7 @@ types can be one of the following "console", "file", "json" or "syslog".
 What log facility class to use. This follows syslog convention. By default 
 the facility is "local6".
 
-=head2 --logfile
+=head2 --log-file
 
 The name of the log file. When --logfile is specified, it implies a log type 
 of "file".
@@ -345,6 +384,14 @@ of "file".
 
 =over 4
 
+=item L<XAS::Lib::App::Daemon|XAS::Lib::App::Daemon>
+
+=item L<XAS::Lib::App::Service|XAS::Lib::App::Service>
+
+=item L<XAS::Lib::App::Service::Unix|XAS::Lib::App::Service::Unix>
+
+=item L<XAS::Lib::App::Service::Win32|XAS::Lib::App::Service::Win32>
+
 =item L<XAS|XAS>
 
 =back
@@ -355,7 +402,7 @@ Kevin L. Esteb, E<lt>kevin@kesteb.usE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014 Kevin L. Esteb
+Copyright (c) 2012-2015 Kevin L. Esteb
 
 This is free software; you can redistribute it and/or modify it under
 the terms of the Artistic License 2.0. For details, see the full text
