@@ -2,13 +2,14 @@ package XAS::Lib::Mixins::Configs;
 
 our $VERSION = '0.01';
 
+use Try::Tiny;
 use Config::IniFiles;
 
 use XAS::Class
   debug   => 0,
   version => $VERSION,
   base    => 'XAS::Base',
-  utils   => 'dotid compress',
+  utils   => ':validation dotid compress',
   mixins  => 'load_config',
 ;
 
@@ -18,22 +19,40 @@ use XAS::Class
 
 sub load_config {
     my $self = shift;
-    my ($filename, $handle) = $self->validate_params(\@_, [
-        { optional => 1, isa => 'Badger::Filesystem::File', default => $self->env->cfgfile },
+    my ($filename, $handle) = validate_params(\@_, [
+        { optional => 1, isa => 'Badger::Filesystem::File', default => $self->env->cfg_file },
         { optional => 1, default => 'cfg' },
     ]);
 
-    $self->{$handle} = Config::IniFiles->new(
-        -file => $filename->path,
-    ) or do {
-        $self->log->warn(compress(join('', @Config::IniFiles::errors)));
+    # really... using carp() as an exception handler is lame
+
+    local $SIG{__WARN__} = sub {
+        my $error = shift;
+
+        my ($reason) = $error =~ /(.*)at\s+/;
+
         $self->throw_msg(
             dotid($self->class) . '.load_config.badini',
             'config_badini',
-            $filename->path
+            $filename->path,
+            $reason,
         );
+
     };
 
+    $self->{$handle} = Config::IniFiles->new(-file => $filename->path);
+
+    unless (defined($self->{$handle})) {
+
+        $self->throw_msg(
+            dotid($self->class) . '.load_config.badini',
+            'config_badini',
+            $filename->path,
+            compress(join('', @Config::IniFiles::errors)),
+        );
+
+    }
+
 }
 
 # ----------------------------------------------------------------------
