@@ -11,7 +11,7 @@ use XAS::Class
   version   => $VERSION,
   base      => 'XAS::Base',
   mixin     => 'XAS::Lib::Mixins::Bufops',
-  utils     => 'trim dotid',
+  utils     => ':validation dotid trim',
   accessors => 'handle select attempts',
   mutators  => 'timeout',
   import    => 'class',
@@ -40,7 +40,7 @@ sub connect {
     $self->class->var('ERRNO', 0);
     $self->class->var('ERRSTR', '');
 
-    $self->{handle} = IO::Socket::INET->new(
+    $self->{'handle'} = IO::Socket::INET->new(
         Proto    => 'tcp',
         PeerPort => $self->port,
         PeerAddr => $self->host,
@@ -64,14 +64,14 @@ sub connect {
     };
 
     $self->handle->blocking(0);
-    $self->{select} = IO::Select->new($self->handle);
+    $self->{'select'} = IO::Select->new($self->handle);
 
 }
 
 sub pending {
     my $self = shift;
 
-    return length($self->{buffer});
+    return length($self->{'buffer'});
 
 }
 
@@ -88,7 +88,7 @@ sub disconnect {
 
 sub get {
     my $self = shift;
-    my ($length) = $self->validate_params(\@_, [
+    my ($length) = validate_params(\@_, [
         { optional => 1, default => 512 }
     ]);
 
@@ -96,14 +96,14 @@ sub get {
 
     if ($self->pending > $length) {
 
-        $output = $self->buf_slurp(\$self->{buffer}, $length);
+        $output = $self->buf_slurp(\$self->{'buffer'}, $length);
 
     } else {
 
         $self->_fill_buffer();
 
         my $l = ($self->pending > $length) ? $length : $self->pending;
-        $output = $self->buf_slurp(\$self->{buffer}, $l);
+        $output = $self->buf_slurp(\$self->{'buffer'}, $l);
 
     }
 
@@ -123,7 +123,7 @@ sub gets {
 
         if ($output = $self->buf_get_line(\$buffer, $self->eol)) {
 
-            $self->{buffer} = $buffer . $self->{buffer};
+            $self->{'buffer'} = $buffer . $self->{'buffer'};
             last;
 
         }
@@ -136,7 +136,7 @@ sub gets {
 
 sub put {
     my $self = shift;
-    my ($buffer) = $self->validate_params(\@_, [1]);
+    my ($buffer) = validate_params(\@_, [1]);
 
     my $counter = 0;
     my $working = 1;
@@ -202,18 +202,18 @@ sub put {
 
 sub puts {
     my $self = shift;
-    my ($buffer) = $self->validate_params(\@_, [1]);
+    my ($buffer) = validate_params(\@_, [1]);
 
     my $data = sprintf("%s%s", trim($buffer), $self->eol);
     my $written = $self->put($data);
-    
+
     return $written;
 
 }
 
 sub errno {
     my $class = shift;
-    my ($value) = XAS::Base->validate_params(\@_, [
+    my ($value) = validate_params(\@_, [
         { optional => 1, default => undef }
     ]);
 
@@ -225,7 +225,7 @@ sub errno {
 
 sub errstr {
     my $class = shift;
-    my ($value) = XAS::Base->validate_params(\@_, [
+    my ($value) = validate_params(\@_, [
         { optional => 1, default => undef }
     ]);
 
@@ -249,8 +249,8 @@ sub init {
 
     my $self = $class->SUPER::init(@_);
 
-    $self->{attempts} = 5;
-    $self->{buffer}   = '';
+    $self->{'attempts'} = 5;
+    $self->{'buffer'}   = '';
 
     return $self;
 
@@ -262,11 +262,13 @@ sub _fill_buffer {
     my $counter = 0;
     my $working = 1;
     my $read    = 0;
-    my $timeout = $self->handle->timeout;
+    my $timeout = $self->timeout;
 
     $self->class->var('ERRNO', 0);
     $self->class->var('ERRSTR', '');
 
+    $self->handle->blocking(0);
+
     while ($working) {
 
         my $buf;
@@ -277,7 +279,7 @@ sub _fill_buffer {
 
             if (my $bytes = $self->handle->sysread($buf, 512)) {
 
-                $self->{buffer} .= $buf;
+                $self->{'buffer'} .= $buf;
                 $read += $bytes;
 
             } else {
@@ -287,7 +289,7 @@ sub _fill_buffer {
                     my $errno  = $! + 0;
                     my $errstr = $!;
 
-                    $self->log->debug("get: errno = $errno");
+                    $self->log->debug("fill_buffer: errno = $errno");
 
                     if ($errno == EAGAIN) {
 
@@ -300,7 +302,7 @@ sub _fill_buffer {
                         $self->class->var('ERRSTR', $errstr);
 
                         $self->throw_msg(
-                            dotid($self->class) . '.get',
+                            dotid($self->class) . '.fill_buffer',
                             'net_client_network',
                             $errstr
                         );
@@ -319,6 +321,8 @@ sub _fill_buffer {
 
     }
 
+    $self->handle->blocking(1);
+
     return $read;
 
 }
@@ -438,6 +442,10 @@ A class method to return the error string.
 
 =over 4
 
+=item L<XAS::Lib::Net::POE::Client|XAS::Lib::Net::POE::Client>
+
+=item L<XAS::Lib::Net::Server|XAS::Lib::Net::Server>
+
 =item L<XAS|XAS>
 
 =back
@@ -446,7 +454,7 @@ A class method to return the error string.
 
 Kevin L. Esteb, E<lt>kevin@kesteb.usE<gt>
 
-Copyright (C) 2014 Kevin L. Esteb
+Copyright (c) 2012-2015 Kevin L. Esteb
 
 This is free software; you can redistribute it and/or modify it under
 the terms of the Artistic License 2.0. For details, see the full text
