@@ -1,6 +1,6 @@
 package XAS::Lib::Net::Server;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use POE;
 use Try::Tiny;
@@ -14,8 +14,8 @@ use XAS::Class
   version   => $VERSION,
   base      => 'XAS::Lib::POE::Service',
   mixin     => 'XAS::Lib::Mixins::Handlers',
-  utils     => 'weaken params',
-  accessors => 'session',
+  utils     => ':validation weaken params',
+  accessors => 'session clients',
   constants => 'ARRAY',
   vars => {
     PARAMS => {
@@ -48,13 +48,11 @@ sub session_initialize {
     $poe_kernel->state('client_input',             $self, '_client_input');
     $poe_kernel->state('client_reaper',            $self, '_client_reaper');
     $poe_kernel->state('client_output',            $self, '_client_output');
+    $poe_kernel->state('client_flushed',           $self, '_client_flushed');
     $poe_kernel->state('client_connected',         $self, '_client_connected');
     $poe_kernel->state('client_connection',        $self, '_client_connection');
     $poe_kernel->state('client_connection_failed', $self, '_client_connection_failed');
 
-    $poe_kernel->state('process_errors',    $self, '_process_errors');
-    $poe_kernel->state('process_request',   $self, '_process_request');
-    $poe_kernel->state('process_response',  $self, '_process_response');
     $poe_kernel->state('handle_connection', $self, '_handle_connection');
 
     # walk the chain
@@ -86,18 +84,18 @@ sub session_shutdown {
     my $self = shift;
 
     my $alias = $self->alias;
-    my $clients = $self->{clients};
+    my @clients = keys %{$self->{'clients'}};
 
     $self->log->debug("$alias: entering session_shutdown()");
 
-    while (my $client = keys %$clients) {
+    foreach my $client (@clients) {
 
-        $poe_kernel->alarm_remove($client->{watchdog});
+        $poe_kernel->alarm_remove($self->clients->{$client}->{'watchdog'});
         $client = undef;
 
     }
 
-    delete $self->{listener};
+    delete $self->{'listener'};
 
     # walk the chain
 
@@ -111,14 +109,14 @@ sub session_pause {
     my $self = shift;
 
     my $alias = $self->alias;
-    my $clients = $self->{clients};
+    my @clients = keys %{$self->{'clients'}};
 
     $self->log->debug("$alias: entering session_pause()");
 
-    while (my $wheel = keys %$clients) {
+    foreach my $client (@clients) {
 
-        $wheel->pause_input();
-        $poe_kernel->alarm_remove($wheel->{watchdog});
+        $client->pause_input();
+        $poe_kernel->alarm_remove($self->clients->{$client}->{'watchdog'});
 
     }
 
@@ -134,15 +132,15 @@ sub session_resume {
     my $self = shift;
 
     my $alias = $self->alias;
-    my $clients = $self->{clients};
+    my @clients = keys %{$self->{'clients'}};
     my $inactivity = $self->inactivity_timer;
 
     $self->log->debug("$alias: entering session_resume()");
 
-    while (my $wheel = keys %$clients) {
+    foreach my $client (@clients) {
 
-        $wheel->resume_input();
-        $poe_kernel->alarm_set('client_reaper', $inactivity, $wheel);
+        $client->resume_input();
+        $self->clients->{$client}->{'watchdog'} = $poe_kernel->alarm_set('client_reaper', $inactivity, $client);
 
     }
 
@@ -156,7 +154,7 @@ sub session_resume {
 
 sub reaper {
     my $self = shift;
-    my ($wheel) = $self->validate_params(\@_, [1]);
+    my ($wheel) = validate_params(\@_, [1]);
 
     my $alias = $self->alias;
 
@@ -166,32 +164,34 @@ sub reaper {
 
 sub process_request {
     my $self = shift;
-    my ($input, $ctx) = $self->validate_params(\@_, [1,1]);
+    my ($input, $ctx) = validate_params(\@_, [1,1]);
 
-    return $input;
+    $self->process_response($input, $ctx);
 
 }
 
 sub process_response {
     my $self = shift;
-    my ($output, $ctx) = $self->validate_params(\@_, [1,1]);
+    my ($output, $ctx) = validate_params(\@_, [1,1]);
 
-    return $output;
+    my $alias = $self->alias;
+
+    $poe_kernel->post($alias, 'client_output', $output, $ctx);
 
 }
 
 sub process_errors {
     my $self = shift;
-    my ($output, $ctx) = $self->validate_params(\@_, [1,1]);
+    my ($errors, $ctx) = validate_params(\@_, [1,1]);
 
-    return $output;
+    $self->process_response($errors, $ctx);
 
 }
 
 sub handle_connection {
     my $self = shift;
-    my ($wheel) = $self->validate_params(\@_, [1]);
-    
+    my ($wheel) = validate_params(\@_, [1]);
+
 }
 
 # ----------------------------------------------------------------------
@@ -200,25 +200,25 @@ sub handle_connection {
 
 sub peerport {
     my $self = shift;
-    my ($wheel) = $self->validate_params(\@_, [1]);
+    my ($wheel) = validate_params(\@_, [1]);
 
-    return $self->{clients}->{$wheel}->{port};
+    return $self->clients->{$wheel}->{'port'};
 
 }
 
 sub peerhost {
     my $self = shift;
-    my ($wheel) = $self->validate_params(\@_, [1]);
+    my ($wheel) = validate_params(\@_, [1]);
 
-    return $self->{clients}->{$wheel}->{host};
+    return $self->clients->{$wheel}->{'host'};
 
 }
 
 sub client {
     my $self = shift;
-    my ($wheel) = $self->validate_params(\@_, [1]);
+    my ($wheel) = validate_params(\@_, [1]);
 
-    return $self->{clients}->{$wheel}->{client};
+    return $self->clients->{$wheel}->{'client'};
 
 }
 
@@ -230,39 +230,6 @@ sub client {
 # Private Events
 # ----------------------------------------------------------------------
 
-sub _process_request {
-    my ($self, $input, $ctx) = @_[OBJECT,ARG0,ARG1];
-
-    my $alias = $self->alias;
-    my $data  = $self->process_request($input, $ctx);
-
-    $self->log->debug("$alias: _process_request()");
-    $poe_kernel->post($alias, 'process_response', $data, $ctx);
-
-}
-
-sub _process_response {
-    my ($self, $output, $ctx) = @_[OBJECT,ARG0,ARG1];
-
-    my $alias = $self->alias;
-    my $data  = $self->process_response($output, $ctx);
-
-    $self->log->debug("$alias: _process_response()");
-    $poe_kernel->post($alias, 'client_output', $data, $ctx);
-
-}
-
-sub _process_errors {
-    my ($self, $output, $ctx) = @_[OBJECT,ARG0,ARG1];
-
-    my $alias = $self->alias;
-    my $data  = $self->process_errors($output, $ctx);
-
-    $self->log->debug("$alias: _process_errors()");
-    $poe_kernel->post($alias, 'client_output', $data, $ctx);
-
-}
-
 sub _handle_connection {
     my ($self, $wheel) = @_[OBJECT, ARG0];
 
@@ -282,7 +249,7 @@ sub _client_connection {
 
     # start listening for connections
 
-    $self->{listener} = POE::Wheel::SocketFactory->new(
+    $self->{'listener'} = POE::Wheel::SocketFactory->new(
         BindAddress    => $self->address,
         BindPort       => $self->port,
         SocketType     => SOCK_STREAM,
@@ -304,21 +271,22 @@ sub _client_connected {
     $self->log->debug("$alias: _client_connected()");
 
     my $client = POE::Wheel::ReadWrite->new(
-        Handle     => $socket,
-        Filter     => $self->filter,
-        InputEvent => 'client_input',
-        ErrorEvent => 'client_error'
+        Handle       => $socket,
+        Filter       => $self->filter,
+        InputEvent   => 'client_input',
+        ErrorEvent   => 'client_error',
+        FlushedEvent => 'client_flushed',
     );
 
     my $wheel = $client->ID;
     my $host = gethostbyaddr($peeraddr, AF_INET);
 
-    $self->{clients}->{$wheel}->{host}   = $host;
-    $self->{clients}->{$wheel}->{port}   = $peerport;
-    $self->{clients}->{$wheel}->{client} = $client;
-    $self->{clients}->{$wheel}->{active} = time();
-    $self->{clients}->{$wheel}->{socket} = $socket;
-    $self->{clients}->{$wheel}->{watchdog} = $poe_kernel->alarm_set('client_reaper', $inactivity, $wheel);
+    $self->{'clients'}->{$wheel}->{'host'}   = $host;
+    $self->{'clients'}->{$wheel}->{'port'}   = $peerport;
+    $self->{'clients'}->{$wheel}->{'client'} = $client;
+    $self->{'clients'}->{$wheel}->{'active'} = time();
+    $self->{'clients'}->{$wheel}->{'socket'} = $socket;
+    $self->{'clients'}->{$wheel}->{'watchdog'} = $poe_kernel->alarm_set('client_reaper', $inactivity, $wheel);
 
     $self->log->info_msg('net_client_connect', $alias, $host, $peerport);
 
@@ -333,7 +301,7 @@ sub _client_connection_failed {
 
     $self->log->error_msg('net_client_connection_failed', $alias, $errnum, $errstr);
 
-    delete $self->{listener};
+    delete $self->{'listener'};
 
 }
 
@@ -347,9 +315,9 @@ sub _client_input {
 
     $self->log->debug("$alias: _client_input()");
 
-    $self->{clients}->{$wheel}->{active} = time();
+    $self->{'clients'}->{$wheel}->{'active'} = time();
 
-    $poe_kernel->post($alias, 'process_request', $input, $ctx);
+    $self->process_request($input, $ctx);
 
 }
 
@@ -357,23 +325,25 @@ sub _client_output {
     my ($self, $data, $ctx) = @_[OBJECT,ARG0,ARG1];
 
     my $alias = $self->alias;
-    my $wheel = $ctx->{wheel};
+    my $wheel = $ctx->{'wheel'};
     my @buffer;
 
     $self->log->debug("$alias: _client_output()");
 
     try {
 
-        if (defined($wheel)) {
+        if (defined($wheel) and defined($self->clients->{$wheel})) {
 
             # emulate IO::Socket connected() method. this method
             # calls getpeername(). getpeername() returns undef when
             # the network stack can't validate the socket. 
 
-            if (getpeername($self->{clients}->{$wheel}->{socket})) {
+            no warnings;
+
+            if (getpeername($self->clients->{$wheel}->{'socket'})) {
 
                 push(@buffer, $data);
-                $self->{clients}->{$wheel}->{client}->put(@buffer);
+                $self->clients->{$wheel}->{'client'}->put(@buffer);
 
             } else {
 
@@ -383,7 +353,7 @@ sub _client_output {
                     $self->peerhist($wheel), 
                     $self->peerport($wheel)
                 );
-                delete $self->{clients}->{$wheel};
+                delete $self->clients->{$wheel};
 
             }
 
@@ -399,7 +369,7 @@ sub _client_output {
 
         $self->exception_handler($ex);
 
-        delete $self->{clients}->{$wheel};
+        delete $self->clients->{$wheel};
 
     };
 
@@ -422,7 +392,7 @@ sub _client_error {
 
     }
 
-    delete $self->{clients}->{$wheel};
+    delete $self->clients->{$wheel};
 
 }
 
@@ -431,14 +401,29 @@ sub _client_reaper {
 
     my $timeout = time() - $self->inactivity_timer;
 
-    if ($self->{clients}->{$wheel}->{active} < $timeout) {
+    if (defined($self->clients->{$wheel})) {
 
-        $self->reaper($wheel);
+        if ($self->clients->{$wheel}->{'active'} < $timeout) {
+
+            $self->reaper($wheel);
+
+        }
 
     }
 
 }
 
+sub _client_flushed {
+    my ($self, $wheel) = @_[OBJECT,ARG0]; 
+
+    my $alias = $self->alias; 
+    my $host  = $self->peerhost($wheel); 
+    my $port  = $self->peerport($wheel); 
+
+    $self->log->debug(sprintf('%s: _client_flushed(), wheel: %s, host: %s, port: %s', $alias, $wheel, $host, $port)); 
+    
+}
+
 # ----------------------------------------------------------------------
 # Private Methods
 # ----------------------------------------------------------------------
@@ -450,7 +435,7 @@ sub init {
 
     unless (defined($self->filter)) {
 
-        $self->{filter} = POE::Filter::Line->new(
+        $self->{'filter'} = POE::Filter::Line->new(
             InputLiteral  => $self->eol,
             OutputLiteral => $self->eol,
         );
@@ -556,7 +541,7 @@ field. Others fields may be added as needed.
 
 =head2 process_response($output, $ctx)
 
-This method will process the output from the client. It takes the
+This method will process the output for the client. It takes the
 following parameters:
 
 =over 4
@@ -572,14 +557,14 @@ output to the correct socket. Others fields may have been added as needed.
 
 =back
 
-=head2 process_errors($output, $ctx)
+=head2 process_errors($errors, $ctx)
 
 This method will process the error output from the client. It takes the
 following parameters:
 
 =over 4
 
-=item B<$output>
+=item B<$errors>
 
 The output to be sent to the socket.
 
@@ -645,6 +630,10 @@ The POE wheel to use.
 
 =over 4
 
+=item L<XAS::Lib::Net::Client|XAS::Lib::Net::Client>
+
+=item L<XAS::Lib::Net::POE::Client|XAS::Lib::Net::POE::Client>
+
 =item L<POE::Filter::Line|https://metacpan.org/pod/POE::Filter::Line>
 
 =item L<XAS|XAS>
@@ -657,7 +646,7 @@ Kevin L. Esteb, E<lt>kevin@kesteb.usE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014 Kevin L. Esteb
+Copyright (c) 2012-2015 Kevin L. Esteb
 
 This is free software; you can redistribute it and/or modify it under
 the terms of the Artistic License 2.0. For details, see the full text
