@@ -18,6 +18,8 @@ use XAS::Class
   }
 ;
 
+use Data::Dumper;
+
 # ----------------------------------------------------------------------
 # Public Events
 # ----------------------------------------------------------------------
@@ -81,10 +83,9 @@ sub session_stop {
 
 sub session_exception {
     my $self = shift;
-    my $hash = shift;
+    my $ex   = shift;
 
     my $alias = $self->alias;
-    my $ex    = $hash->{'error_str'};
 
     $self->log->debug("$alias: session_exception() - session");
     $self->error_handler($ex);
@@ -105,17 +106,13 @@ sub run {
 sub init {
     my $class = shift;
 
-    # initialize POE, this removes an error message if a failure happens later
-
-#    $poe_kernel->run();
-
     # walk the chain
 
     my $self = $class->SUPER::init(@_);
 
     # set up the session
 
-    $self->{session} = POE::Session->create(
+    $self->{'session'} = POE::Session->create(
         object_states => [
             $self => {
                 _start            => '_session_start',
@@ -130,7 +127,7 @@ sub init {
         ]
     );
 
-    weaken($self->{session});
+    weaken($self->{'session'});
 
     return $self;
 
@@ -215,6 +212,8 @@ sub _session_stop {
 
     $self->log->debug("$alias: _session_stop()");
 
+    $poe_kernel->sig('DIE');
+
     $self->session_stop();
 
     $poe_kernel->alias_remove($self->alias);
@@ -239,21 +238,17 @@ sub _session_exception {
 
     $self->log->debug("$alias: _session_exception()");
 
-    $self->log->debug(sprintf("%s: file:  %s", $alias, $ex->{'file'}));
-    $self->log->debug(sprintf("%s: line:  %s", $alias, $ex->{'line'}));
-    $self->log->debug(sprintf("%s: state: %s", $alias, $ex->{'from_state'} || ''));
-    $self->log->debug(sprintf("%s: source: %s", $alias, $ex->{'source_session'} || ''));
-    $self->log->debug(sprintf("%s: destinaion: %s", $alias, $ex->{'dest_session'} || ''));
-
     $poe_kernel->sig_handled();
 
     if ($ex->{'source_session'} ne $_[SESSION]) {
 
-        $poe_kernel->signal($ex->{'source_session'}, 'DIE', $sig, $ex);
+        $self->log->debug(sprintf('%s: sending execption to: %s', $alias, $ex->{'source_session'}));
+        $poe_kernel->post($ex->{'source_session'}, 'session_exception', $sig, $ex);
 
     } else {
 
-        $self->session_exception($ex);
+        $self->log->debug(sprintf('%s: handling execption: %s', $alias, $ex->{'error_str'}));
+        $self->session_exception($ex->{'error_str'});
 
     }
 
