@@ -1,6 +1,6 @@
 package XAS::Lib::Process;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 my $mixin;
 
@@ -10,35 +10,44 @@ BEGIN {
 }
 
 use Set::Light;
-use Badger::Filesystem 'Cwd Dir';
+use Hash::Merge;
+use Badger::Filesystem 'Cwd Dir File';
+use XAS::Constants ':process CODEREF';
 use POE qw(Wheel Driver::SysRW Filter::Line);
 
 use XAS::Class
   debug     => 0,
   version   => $VERSION,
   base      => 'XAS::Lib::POE::Service',
-  mixin     => $mixin,
-  utils     => 'dotid',
-  mutators  => 'is_active input_handle output_handle status retries',
-  accessors => 'pid exit_code exit_signal process ID',
+  mixin     => "XAS::Lib::Mixins::Process $mixin",
+  utils     => ':validation dotid trim',
+  mutators  => 'input_handle output_handle status retries',
+  accessors => 'pid exit_code exit_signal process ID merger',
   vars => {
     PARAMS => {
-      -command       => 1,
-      -auto_start    => { optional => 1, default => 1 },
-      -auto_restart  => { optional => 1, default => 1 },
-      -environment   => { optional => 1, default => {} },
-      -exit_codes    => { optional => 1, default => '0,1' },
-      -exit_retries  => { optional => 1, default => 5 },
-      -group         => { optional => 1, default => 'nobody' },
-      -priority      => { optional => 1, default => 0 },
-      -umask         => { optional => 1, default => '0022' },
-      -user          => { optional => 1, default => 'nobody' },
-      -redirect      => { optional => 1, default => 0 },
-      -input_driver  => { optional => 1, default => POE::Driver::SysRW->new() },
-      -output_driver => { optional => 1, default => POE::Driver::SysRW->new() },
-      -input_filter  => { optional => 1, default => POE::Filter::Line->new(Literal => "\n") },
-      -output_filter => { optional => 1, default => POE::Filter::Line->new(Literal => "\n") },
-      -directory     => { optional => 1, default => Cwd, isa => 'Badger::Filesystem::Directory' },
+      -command        => 1,
+      -auto_start     => { optional => 1, default => 1 },
+      -auto_restart   => { optional => 1, default => 1 },
+      -environment    => { optional => 1, default => {} },
+      -exit_codes     => { optional => 1, default => '0,1' },
+      -exit_retries   => { optional => 1, default => 5 },
+      -group          => { optional => 1, default => 'nobody' },
+      -priority       => { optional => 1, default => 0 },
+      -pty            => { optional => 1, default => 0 },
+      -umask          => { optional => 1, default => '0022' },
+      -user           => { optional => 1, default => 'nobody' },
+      -redirect       => { optional => 1, default => 0 },
+      -retry_delay    => { optional => 1, default => 0 },
+      -input_driver   => { optional => 1, default => POE::Driver::SysRW->new() },
+      -output_driver  => { optional => 1, default => POE::Driver::SysRW->new() },
+      -input_filter   => { optional => 1, default => POE::Filter::Line->new(Literal => "\n") },
+      -output_filter  => { optional => 1, default => POE::Filter::Line->new(Literal => "\n") },
+      -directory      => { optional => 1, default => Cwd, isa => 'Badger::Filesystem::Directory' },
+      -output_handler => { optional => 1, type => CODEREF, default => sub {
+              my $output = shift;
+              printf("%s\n", trim($output));
+          }
+      },
     }
   }
 ;
@@ -56,13 +65,20 @@ sub session_initialize {
 
     $self->log->debug("$alias: entering session_initialize()");
 
-    $poe_kernel->state('get_output',  $self);
-    $poe_kernel->state('put_input',   $self);
-    $poe_kernel->state('flush_event', $self);
-    $poe_kernel->state('error_event', $self);
-    $poe_kernel->state('close_event', $self);
-    $poe_kernel->state('poll_child',  $self, '_poll_child');
-    $poe_kernel->state('child_exit',  $self, '_child_exit');
+    $poe_kernel->state('get_event',    $self, '_get_event');
+    $poe_kernel->state('flush_event',  $self, '_flush_event');
+    $poe_kernel->state('error_event',  $self, '_error_event');
+    $poe_kernel->state('close_event',  $self, '_close_event');
+    $poe_kernel->state('check_status', $self, '_check_status');
+    $poe_kernel->state('poll_child',   $self, '_poll_child');
+    $poe_kernel->state('child_exit',   $self, '_child_exit');
+
+    $poe_kernel->state('start_process',  $self, '_start_process');
+    $poe_kernel->state('stop_process',   $self, '_stop_process');
+    $poe_kernel->state('pause_process',  $self, '_pause_process');
+    $poe_kernel->state('resume_process', $self, '_resume_process');
+    $poe_kernel->state('kill_process',   $self, '_kill_process');
+
 
     # walk the chain
 
@@ -83,8 +99,8 @@ sub session_startup {
 
     if ($self->auto_start) {
 
-        $self->start_process();
-
+        $poe_kernel->call($alias, 'start_process');
+        
     }
 
     # walk the chain
@@ -102,8 +118,8 @@ sub session_pause {
 
     $self->log->debug("$alias: entering session_pause()");
 
-    $self->pause_process();
-
+    $poe_kernel->call($alias, 'pause_process');
+    
     # walk the chain
 
     $self->SUPER::session_pause();
@@ -119,7 +135,7 @@ sub session_resume {
 
     $self->log->debug("$alias: entering session_resume()");
 
-    $self->resume_process();
+    $poe_kernel->call($alias, 'resume_process');
 
     # walk the chain
 
@@ -136,7 +152,8 @@ sub session_stop {
 
     $self->log->debug("$alias: entering session_stop()");
 
-    $self->stop_process();
+    $self->kill_process();
+    $poe_kernel->sig_handled();
 
     # walk the chain
 
@@ -153,8 +170,11 @@ sub session_shutdown {
 
     $self->log->debug("$alias: entering session_shutdown()");
 
-    $self->kill_process();
+    $self->status(PROC_SHUTDOWN);
 
+    $poe_kernel->call($alias, 'stop_process');
+    $poe_kernel->sig_handled();
+  
     # walk the chain
 
     $self->SUPER::session_shutdown();
@@ -163,19 +183,9 @@ sub session_shutdown {
 
 }
 
-# ----------------------------------------------------------------------
-# Public Events
-# ----------------------------------------------------------------------
-
-sub get_output {
-    my ($self, $output, $wheel) = @_[OBJECT,ARG0,ARG1];
-
-    print $output . "\n";
-
-}
-
-sub put_input {
-    my ($self, $chunk) = @_[OBJECT,ARG0];
+sub put {
+    my $self = shift;
+    my ($chunk) = validate_params(\@_, [1]);
 
     my @chunks;
     my $driver = $self->input_driver;
@@ -195,7 +205,7 @@ sub put_input {
  
     push(@chunks, $chunk);
 
-    if ($self->{buffer} = $driver->put($filter->put(\@chunks))) {
+    if ($self->{'buffer'} = $driver->put($filter->put(\@chunks))) {
 
         $poe_kernel->select_resume_write($self->input_handle);
 
@@ -205,7 +215,167 @@ sub put_input {
 
 }
 
-sub flush_event {
+sub DESTROY {
+    my $self = shift;
+
+    if ($self->input_handle) {
+
+        $poe_kernel->select_write($self->input_handle);
+        $self->input_handle(undef);
+
+    }
+
+    if ($self->output_handle) {
+
+        $poe_kernel->select_read($self->output_handle);
+        $self->output_handle(undef);
+
+    }
+
+    $self->destroy();
+
+    POE::Wheel::free_wheel_id($self->ID);
+
+}
+
+# ----------------------------------------------------------------------
+# Public Events
+# ----------------------------------------------------------------------
+
+# ----------------------------------------------------------------------
+# Private Events
+# ----------------------------------------------------------------------
+
+sub _start_process {
+    my $self = $_[OBJECT];
+
+    my $count = 1;
+    my $alias = $self->alias;
+
+    if ($self->status == PROC_STOPPED) {
+
+        $self->start_process();
+        $poe_kernel->post($alias, 'check_status', $count);
+
+    }
+
+}
+
+sub _resume_process {
+    my $self = $_[OBJECT];
+
+    my $count = 1;
+    my $alias = $self->alias;
+
+    $self->resume_process();
+    $poe_kernel->post($alias, 'check_status', $count);
+
+}
+
+sub _pause_process {
+    my $self = $_[OBJECT];
+
+    my $count = 1;
+    my $alias = $self->alias;
+
+    $self->pause_process();
+    $poe_kernel->post($alias, 'check_status', $count);
+
+}
+
+sub _stop_process {
+    my $self = $_[OBJECT];
+
+    my $count = 1;
+    my $alias = $self->alias;
+
+    $self->stop_process();
+    $poe_kernel->post($alias, 'check_status', $count);
+
+}
+
+sub _kill_process {
+    my $self = $_[OBJECT];
+
+    my $count = 1;
+    my $alias = $self->alias;
+
+    $self->kill_process();
+    $poe_kernel->post($alias, 'check_status', $count);
+
+}
+
+sub _get_event {
+    my ($self, $output, $wheel) = @_[OBJECT,ARG0,ARG1];
+
+    $self->output_handler->($output);
+
+}
+
+sub _check_status {
+    my ($self, $count) = @_[OBJECT, ARG0];
+
+    my $alias = $self->alias;
+    my $stat = $self->stat_process();
+
+    $self->log->debug(sprintf('%s: check_status: process: %s, status: %s, count %s', $alias, $stat, $self->status, $count));
+
+    $count++;
+
+    if ($self->status == PROC_STARTED) {
+
+        if (($stat == 3) || ($stat == 2)) {
+
+            $self->status(PROC_RUNNING);
+            $self->log->info_msg('process_started', $alias, $self->pid);
+
+        } else {
+
+            $poe_kernel->delay('check_status', 5, $count);
+
+        }
+
+    } elsif ($self->status == PROC_RUNNING) {
+
+        if (($stat != 3) || ($stat != 2)) {
+
+            $self->resume_process();
+            $poe_kernel->delay('check_status', 5, $count);
+
+        }
+
+    } elsif ($self->status == PROC_PAUSED) {
+
+        if ($stat != 6) {
+
+            $self->pause_process();
+            $poe_kernel->delay('check_status', 5, $count);
+
+        }
+
+    } elsif ($self->status == PROC_STOPPED) {
+
+        if ($stat != 0) {
+
+            $self->stop_process();
+            $poe_kernel->delay('check_status', 5, $count);
+
+        }
+
+    } elsif($self->status == PROC_KILLED) {
+
+        if ($stat != 0) {
+
+            $self->kill_process();
+            $poe_kernel->delay('check_status', 5, $count);
+
+        }
+
+    }
+
+}
+
+sub _flush_event {
     my ($self, $wheel) = @_[OBJECT,ARG0];
 
     my $alias = $self->alias;
@@ -214,7 +384,7 @@ sub flush_event {
 
 }
 
-sub error_event {
+sub _error_event {
     my ($self, $operation, $errno, $errstr, $wheel, $type) = @_[OBJECT,ARG0..ARG4];
 
     my $alias = $self->alias;
@@ -226,54 +396,69 @@ sub error_event {
 
 }
 
-sub close_event {
+sub _close_event {
     my ($self, $wheel) = @_[OBJECT,ARG0];
 
     my $alias = $self->alias;
 
     $self->log->debug("$alias: close_event");
 
+    $poe_kernel->select_write($self->input_handle);
+    $self->input_handle(undef);
+
+    $poe_kernel->select_read($self->output_handle);
+    $self->output_handle(undef);
+
 }
 
-# ----------------------------------------------------------------------
-# Private Methods
-# ----------------------------------------------------------------------
-
 sub _child_exit {
-    my ($self, $signal, $pid, $exitcode) = @_[OBJECT,ARG0,ARG1,ARG2];
+    my ($self, $signal, $pid, $exitcode) = @_[OBJECT,ARG0...ARG2];
 
     my $alias   = $self->alias;
     my $status  = $self->status;
     my $retries = $self->retries;
 
-    $self->{pid}         = undef;
-    $self->{exit_code}   = $exitcode >> 8;
-    $self->{exit_signal} = $exitcode & 127;
+    $self->{'pid'}         = undef;
+    $self->{'exit_code'}   = $exitcode >> 8;
+    $self->{'exit_signal'} = $exitcode & 127;
 
-    $self->log->warn_msg('process_exited', $alias, $pid, $self->exit_code);
+    $self->log->warn_msg('process_exited', $alias, $pid, $self->exit_code, $self->exit_signal);
 
-    if ($status == STOPPED) {
+    if ($status == PROC_STOPPED) {
 
         if ($self->auto_restart) {
 
-            if ($retries < $self->exit_retries) {
+            if (($retries < $self->exit_retries) || ($self->exit_retries < 0)) {
 
                 $retries += 1;
                 $self->retries($retries);
 
                 if ($self->exit_codes->has($self->exit_code)) {
 
-                    $self->start_process();
+                    if ($self->retry_delay) {
+
+                        $poe_kernel->delay('start_process', $self->retry_delay);
+
+                    } else {
+
+                        $poe_kernel->call($alias, 'start_process');
+
+                    }
 
                 } else {
 
-                    $self->log->warn_msg('process_unknown_exitcode', $alias);
+                    $self->log->warn_msg(
+                        'process_unknown_exitcode', 
+                        $alias,
+                        $self->exit_code || '',
+                        $self->exit_signal || '',
+                    );
 
                 }
 
             } else {
 
-                $self->log->warn_msg('process_nomore_retries', $alias);
+                $self->log->warn_msg('process_nomore_retries', $alias, $retries);
 
             }
 
@@ -287,15 +472,20 @@ sub _child_exit {
 
 }
 
-sub _process_output {
-    my $self   = shift;
+# ----------------------------------------------------------------------
+# Private Methods
+# ----------------------------------------------------------------------
 
-    my $id         = $self->ID;
-    my $is_active  = $self->is_active;
-    my $driver     = $self->output_driver;
-    my $filter     = $self->output_filter;
-    my $output     = $self->output_handle;
-    my $state      = ref($self) . "($id) -> select output";
+# stolen from POE::Wheel::Run - more or less
+
+sub _process_output {
+    my $self = shift;
+
+    my $id     = $self->ID;
+    my $driver = $self->output_driver;
+    my $filter = $self->output_filter;
+    my $output = $self->output_handle;
+    my $state  = ref($self) . "($id) -> select output";
 
     if ($filter->can('get_one') and $filter->can('get_one_start')) {
 
@@ -303,21 +493,19 @@ sub _process_output {
             $state,
             sub {
                 my ($k, $me, $handle) = @_[KERNEL, SESSION, ARG0];
-                if (defined(my $raw_output = $driver->get($handle))) {
-                    $filter->get_one_start($raw_output);
+                if (defined(my $raw = $driver->get($handle))) {
+                    $filter->get_one_start($raw);
                     while (1) {
                         my $next_rec = $filter->get_one();
                         last unless @$next_rec;
-                        foreach my $cooked_output (@$next_rec) {
-                            $k->call($me, 'get_output', $cooked_output, $id);
+                        foreach my $cooked (@$next_rec) {
+                            $k->call($me, 'get_event', $cooked, $id);
                         }
                     }
                 } else {
                     $k->call($me, 'error_event', 'read', ($!+0), $!, $id, 'OUTPUT');
-                    unless (--$is_active) {
-                        $k->call($me, 'close_event', $id);
-                    }
-                    $k->select_read($output);
+                    $k->call($me, 'close_event', $id);
+                    $k->select_read($handle);
                 }
             }
         );
@@ -328,16 +516,14 @@ sub _process_output {
             $state,
             sub {
                 my ($k, $me, $handle) = @_[KERNEL, SESSION, ARG0];
-                if (defined(my $raw_output = $driver->get($handle))) {
-                    foreach my $cooked_output (@{$filter->get($raw_output)}) {
-                        $k->call($me, 'get_output', $cooked_output, $id);
+                if (defined(my $raw = $driver->get($handle))) {
+                    foreach my $cooked (@{$filter->get($raw)}) {
+                        $k->call($me, 'get_event', $cooked, $id);
                     }
                 } else {
                     $k->call($me, 'error_event', 'read', ($!+0), $!, $id, 'OUTPUT');
-                    unless (--$is_active) {
-                        $k->call($me, 'close_event', $id);
-                    }
-                    $k->select_read($output);
+                    $k->call($me, 'close_event', $id);
+                    $k->select_read($handle);
                 }
             }
         );
@@ -351,12 +537,12 @@ sub _process_output {
 sub _process_input {
     my $self = shift;
 
-    my $id          = $self->ID;
-    my $driver      = $self->input_driver;
-    my $filter      = $self->input_filter;
-    my $input       = $self->input_handle;
-    my $buffer      = \$self->{buffer};
-    my $state       = ref($self) . "($id) -> select input";
+    my $id     = $self->ID;
+    my $driver = $self->input_driver;
+    my $filter = $self->input_filter;
+    my $input  = $self->input_handle;
+    my $buffer = \$self->{'buffer'};
+    my $state  = ref($self) . "($id) -> select input";
 
     $poe_kernel->state(
         $state,
@@ -387,87 +573,62 @@ sub _process_input {
 
 }
 
-sub DESTROY {
-    my $self = shift;
-
-    if ($self->input_handle) {
-
-        $poe_kernel->select_write($self->input_handle);
-        $self->input_handle(undef);
-
-    }
-
-    if ($self->output_handle) {
-
-        $poe_kernel->select_read($self->output_handle);
-        $self->output_handle(undef);
-
-    }
-
-    POE::Wheel::free_wheel_id($self->ID);
-
-}
+# Stolen from Proc::Background - more or less
 
 sub _resolve_path {
-    my $self               = shift;
-    my $command            = shift;
-    my $is_absolute_re     = shift;
-    my $has_dir_element_re = shift;
-    my $extensions         = shift;
-    my $xpath              = shift;
-    
-    # Stolen from Proc::Background
-    #
+    my $self       = shift;
+    my $command    = shift;
+    my $extensions = shift;
+    my $xpaths     = shift;
+
     # Make the path to the progam absolute if it isn't already.  If the
     # path is not absolute and if the path contains a directory element
     # separator, then only prepend the current working to it.  If the
     # path is not absolute, then look through the PATH environment to
-    # find the executable.  In all cases, look for the programs with any
-    # extensions added to the original path name.
-  
-    my $path;
-    
-    if ($command =~ /$is_absolute_re/o) {
+    # find the executable.
 
-        foreach my $ext (@$extensions) {
+    my $alias = $self->alias;
+    my $path = File($command);
 
-            my $p = "$command$ext";
+    if ($path->is_absolute) {
 
-            if (-f $p and -x _) {
+        if ($path->exists) {
 
-                $path = $p;
-                last;
-
-            }
-
-        }
-        
-        unless (defined $path) {
-
-            $self->throw_msg(
-                dotid($self->class) . '.resolve_path.path',
-                'process_location',
-                $command
-            );
+            return $path->absolute;
 
         }
 
-    } else {
+    } elsif ($path->is_relative) {
 
-        my $cwd = Cwd->path;
+        if ($path->name eq $path) {
 
-        if ($command =~ /$has_dir_element_re/o) {
+            foreach my $xpath (@$xpaths) {
 
-            my $p1 = "$cwd/$command";
+                next if ($xpath eq '');
 
-            foreach my $ext (@$extensions) {
+                if ($path->extension) {
 
-                my $p2 = "$p1$ext";
+                    my $p = File($xpath, $path->name);
 
-                if (-f $p2 and -x _) {
+                    if ($p->exists) {
 
-                    $path = $p2;
-                    last;
+                        return $p->absolute;
+
+                    }
+
+                } else {
+
+                    foreach my $ext (@$extensions) {
+
+                        my $p = File($xpath, $path->basename . $ext);
+
+                        if ($p->exists) {
+
+                            return $p->absolute;
+
+                        }
+
+                    }
 
                 }
 
@@ -475,44 +636,24 @@ sub _resolve_path {
 
         } else {
 
-            foreach my $dir (@$xpath) {
+            my $p = File($path->absoulte);
 
-                next unless length $dir;
+            if ($p->exists) {
 
-                $dir = "$cwd/$dir" unless $dir =~ /$is_absolute_re/o;
-                my $p1 = "$dir/$command";
-            
-                foreach my $ext (@$extensions) {
-
-                    my $p2 = "$p1$ext";
-                    if (-f $p2 and -x _) {
-
-                        $path = $p2;
-                        last;
-
-                    }
-
-                }
-
-                last if defined $path;
+                return $p->absolute;
 
             }
 
         }
 
-        unless (defined $path) {
-
-            $self->throw_msg(
-                dotid($self->class) . '.resolve_path.path',
-                'process_location',
-                $command
-            );
-
-        }
-
     }
 
-    return $path;
+    $self->throw_msg(
+        dotid($self->class) . '.resolve_path.path',
+        'location',
+        $alias, $command
+    );
+
 
 }
 
@@ -523,12 +664,13 @@ sub init {
 
     my @exit_codes = split(',', $self->exit_codes);
 
-    $self->{exit_codes} = Set::Light->new(@exit_codes);
-    $self->{ID}         = POE::Wheel::allocate_wheel_id();
+    $self->{'exit_codes'} = Set::Light->new(@exit_codes);
+    $self->{'ID'}         = POE::Wheel::allocate_wheel_id();
+    $self->{'merger'}     = Hash::Merge->new('RIGHT_PRECEDENT');
 
     $self->retries(1);
-    $self->is_active(1);
     $self->init_process();
+    $self->status(PROC_STOPPED);
 
     return $self;
 
@@ -567,19 +709,19 @@ This method initialized the module and takes the following parameters:
 
 =over 4
 
-=item B<-command>
-
-The command to run.
-
 =item B<-auto_start>
 
-This indicates wither to autostart the process. The default is true.
+This indicates wither to auto start the process. The default is true.
 
 =item B<-auto_restart>
 
-This indicates wither to restart the process if it exits. The default
+This indicates wither to auto restart the process if it exits. The default
 is true.
 
+=item B<-command>
+
+The command to run.
+
 =item B<-directory>
 
 The optional directory to start the process in. Defaults to the current
@@ -587,7 +729,7 @@ directory of the parent process.
 
 =item B<-environment>
 
-Optional, addtitional environment variables to provide to the process.
+Optional, additional environment variables to provide to the process.
 The default is none.
 
 =item B<-exit_codes>
@@ -631,6 +773,11 @@ child process.
 
 The default is no.
 
+=item B<-retry_delay>
+
+The optional number of seconds to delay a retry on an auto restart process.
+The default is 0, or no delay in restarting the process.
+
 =item B<-input_driver>
 
 The optional input driver to use. Defaults to POE::Driver::SysRW.
@@ -647,71 +794,27 @@ The optional filter to use for input. Defaults to POE::Filter::Line.
 
 The optional output filter to use. Defaults to POE::Filter::Line.
 
-=back
+=item B<-output_handler>
 
-=head1 PUBLIC EVENTS
-
-The following public events have been defined. The following arguments
-are provided by POE as offsets into the argument array.
-
-=head2 put_input(OBJECT, ARG0)
-
-This event will write a buffer to stdin.
-
-=over 4
-
-=item B<ARGO> is the buffer to write out.
+This is an optional coderef to handle output from the process. The coderef
+takes one parameter, the output from the process.
 
 =back
 
-=head2 get_output(OBJECT, ARG0, ARG1)
+=head1 METHODS
 
-This event will read a buffer for stdout/stderr.
+=head2 put($data)
 
-=over
-
-=item B<ARG0> is the buffer.
-
-=item B<ARG1> is the wheel ID.
-
-=back
-
-=head2 flush_event(OBJECT, ARG0)
-
-This event is fired when a flush event happens on stdin.
-
-=over 4
-
-=item B<ARG0> is the wheel id that the event happened too.
-
-=back
-
-=head2 error_event(OBJECT, ARG0..ARG4)
-
-This event is fired whenever an error occurs.  
-
-=over 4
-
-=item B<ARG0> - the operation that was being performed i.e. read/write
-
-=item B<ARG1> - the errno that occurred
-
-=item B<ARG2> - the errstr for that errno
-
-=item B<ARG3> - the wheel ID
-
-=item B<ARG4> - the type i.e. INPUT/OUTPUT
-
-=back
-
-=head2 close_event(OBJECT)
-
-This event is fired when a "close" happens on the sockets.
+This method will write a buffer to stdin.
 
 =head1 SEE ALSO
 
 =over 4
 
+=item L<XAS::Lib::Process::Unix|XAS::Lib::Process::Unix>
+
+=item L<XAS::Lib::Process::Win32|XAS::Lib::Process::Win32>
+
 =item L<XAS|XAS>
 
 =back
@@ -722,7 +825,7 @@ Kevin L. Esteb, E<lt>kevin@kesteb.usE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2015 Kevin L. Esteb
+Copyright (c) 2012-2015 Kevin L. Esteb
 
 This is free software; you can redistribute it and/or modify it under
 the terms of the Artistic License 2.0. For details, see the full text
