@@ -11,7 +11,7 @@ use XAS::Class
   version   => $VERSION,
   base      => 'XAS::Lib::POE::Session',
   accessors => 'client peerhost peerport',
-  utils     => 'trim',
+  utils     => ':validation trim',
   vars => {
     PARAMS => {
       -filter => { optional => 1, default => undef },
@@ -49,10 +49,10 @@ sub session_initialize {
 
     # Find the remote host and port.
 
-    my ($rhost, $rport, $lhost, $lport) = split(' ', $ENV{SSH_CONNECTION});
+    my ($rhost, $rport, $lhost, $lport) = split(' ', $ENV{'SSH_CONNECTION'});
 
-    $self->{peerhost} = $rhost;
-    $self->{peerport} = $rport;
+    $self->{'peerhost'} = $rhost;
+    $self->{'peerport'} = $rport;
 
     # walk the chain
 
@@ -83,7 +83,7 @@ sub session_startup {
 
 sub process_request {
     my $self = shift;
-    my ($input, $ctx) = $self->validate_params(\@_, [1,1]);
+    my ($input, $ctx) = validate_params(\@_, [1,1]);
 
     return $input;
 
@@ -91,7 +91,7 @@ sub process_request {
 
 sub process_response {
     my $self = shift;
-    my ($output, $ctx) = $self->validate_params(\@_, [1,1]);
+    my ($output, $ctx) = validate_params(\@_, [1,1]);
 
     return $output;
 
@@ -99,7 +99,7 @@ sub process_response {
 
 sub process_errors {
     my $self = shift;
-    my ($output, $ctx) = $self->validate_params(\@_, [1,1]);
+    my ($output, $ctx) = validate_params(\@_, [1,1]);
 
     return $output;
 
@@ -107,7 +107,7 @@ sub process_errors {
 
 sub handle_connection {
     my $self = shift;
-    my ($wheel) = $self->validate_params(\@_, [1]);
+    my ($wheel) = validate_params(\@_, [1]);
 
 }
 
@@ -157,7 +157,7 @@ sub _handle_connection {
     
     my $alias = $self->alias;
 
-    $self->log->debug("$alias: process_errors()");
+    $self->log->debug("$alias: handle_connection()");
     $self->handle_connection($wheel);
 
 }
@@ -171,7 +171,7 @@ sub _client_connection {
 
     # Start listening on stdin.
 
-    $self->{client} = POE::Wheel::ReadWrite->new(
+    $self->{'client'} = POE::Wheel::ReadWrite->new(
         InputHandle  => \*STDIN,
         OutputHandle => \*STDOUT,
         Filter       => $self->filter,
@@ -232,7 +232,7 @@ sub _client_error {
 
         $self->log->info_msg('net_server_disconnect', $alias, $self->peerhost, $self->peerport);
 
-        delete $self->{client};
+        delete $self->{'client'};
         $poe_kernel->post($alias, 'session_shutdown');
 
     } else {
@@ -254,7 +254,7 @@ sub init {
 
     unless (defined($self->filter)) {
 
-        $self->{filter} = POE::Filter::Line->new(
+        $self->{'filter'} = POE::Filter::Line->new(
             InputLiteral  => $self->eol,
             OutputLiteral => $self->eol
         );
@@ -395,6 +395,8 @@ This returns the peers host name.
 
 =over 4
 
+=item L<XAS::Lib::SSH::Client|XAS::Lib::SSH::Client>
+
 =item L<XAS|XAS>
 
 =back
@@ -405,7 +407,7 @@ Kevin L. Esteb, E<lt>kevin@kesteb.usE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014 Kevin L. Esteb
+Copyright (c) 2012-2015 Kevin L. Esteb
 
 This is free software; you can redistribute it and/or modify it under
 the terms of the Artistic License 2.0. For details, see the full text
